@@ -163,6 +163,17 @@ QC71_TRIPLE_PROFILE_FROM_UPOWER = {
     SLB_EVENT_UPOWER_PERFORMANCE : slimbook.info.SLB_QC71_PROFILE_PERFORMANCE
 }
 
+QC71_DOUBLE_PROFILE_TO_NOTIFICATION = {
+    slimbook.info.SLB_QC71_PROFILE_ENERGY_SAVER : SLB_EVENT_QC71_SILENT_MODE_ON,
+    slimbook.info.SLB_QC71_PROFILE_BALANCED : SLB_EVENT_QC71_SILENT_MODE_OFF
+}
+
+QC71_TRIPLE_PROFILE_TO_NOTIFICATION = {
+    slimbook.info.SLB_QC71_PROFILE_ENERGY_SAVER : SLB_EVENT_ENERGY_SAVER_MODE,
+    slimbook.info.SLB_QC71_PROFILE_BALANCED : SLB_EVENT_BALANCED_MODE,
+    slimbook.info.SLB_QC71_PROFILE_PERFORMANCE : SLB_EVENT_PERFORMANCE_MODE
+}
+
 #set a default dark theme for kde
 xdg_current_desktop = os.environ.get("XDG_CURRENT_DESKTOP")
 if xdg_current_desktop == "KDE":
