@@ -56,6 +56,9 @@ os.chmod(common.SLB_IPC_CTL_PATH, 0o777)
 
 slb_events = queue.Queue()
 
+# whenever platform driver is loaded or not
+module_loaded = False
+
 settings = {
     common.OPT_TRACKPAD_LOCK: True,
     common.OPT_POWER_PROFILE: True
@@ -110,10 +113,13 @@ def upower_worker():
 
 def udev_worker():
     context = pyudev.Context()
-    
+    last_ac_status = -1
+
     for device in context.list_devices(subsystem="power_supply"):
         status = get_udev_ac_status(device)
+
         if (status >=0):
+            last_ac_status = status
             logger.info("AC status:{0}".format(status))
             slb_events.put(common.SLB_EVENT_AC_OFFLINE + status)
     
@@ -121,13 +127,14 @@ def udev_worker():
         if device.get("ID_PATH") == "platform-qc71_laptop":
             if (device.get("DEVNAME")):
                 slb_events.put(common.SLB_EVENT_QC71_INPUT_LOADED)
-            
+
     monitor = pyudev.Monitor.from_netlink(context)
     #monitor.filter_by('power_supply')
     for device in iter(monitor.poll, None):
         if device.subsystem == "power_supply":
             status = get_udev_ac_status(device)
-            if (status >=0):
+            if (status >=0 and status != last_ac_status):
+                last_ac_status = status
                 logger.info("AC status:{0}".format(status))
                 slb_events.put(common.SLB_EVENT_AC_OFFLINE + status)
         elif device.subsystem == "input":
@@ -185,7 +192,7 @@ def keyboard_worker():
             if (event.value == slimbook.info.SLB_SCAN_QC71_SUPER_LOCK):
                 slb_events.put(common.SLB_EVENT_QC71_SUPER_LOCK_CHANGED)
             
-            elif (event.value == slimbook.info.SLB_SCAN_QC71_SILENT_MODE):
+            elif (event.value == slimbook.info.SLB_SCAN_QC71_SILENT_MODE and module_loaded == False):
                 logger.debug("qc71 performance change requested (i8042)")
                 slb_events.put(common.SLB_EVENT_QC71_SILENT_MODE_CHANGED)
             
@@ -296,22 +303,23 @@ def main():
     cached_events = {}
     expect_upower_event = False
     ac = False
+    restore_profile = slimbook.info.SLB_QC71_PROFILE_BALANCED
     
     while True:
        
         event = slb_events.get()
         now = time.time()
         
-        logger.debug("event {0}".format(event))
+        logger.debug("event {0:04X}".format(event))
         
         cached = cached_events.get(event)
         
         if cached:
             delta =  now - cached
-            if delta > 0.750:
+            if delta > 1.250:
                 cached_events[event] = now
             else:
-                logger.debug("ignored duplicated event {0} ({1})".format(event,delta))
+                logger.debug("ignored duplicated event {0:04X} ({1})".format(event,delta))
                 continue
         else:
             cached_events[event] = now
@@ -393,35 +401,45 @@ def main():
 
                 elif (event == common.SLB_EVENT_AC_OFFLINE):
                     ac = False
-
-                    if (family == slimbook.info.SLB_MODEL_CREATIVE or family == slimbook.info.SLB_MODEL_EVO):
+                    logger.debug("AC Offline")
+                    if ((family == slimbook.info.SLB_MODEL_CREATIVE or family == slimbook.info.SLB_MODEL_EVO) and module_loaded):
+                        restore_profile = slimbook.qc71.profile_get()
+                        slimbook.qc71.profile_set(slimbook.info.SLB_QC71_PROFILE_BALANCED)
                         slimbook.qc71.profile_set(slimbook.info.SLB_QC71_PROFILE_ENERGY_SAVER)
-                        event = common.SLB_EVENT_QC71_DYNAMIC_MODE
+                        event = common.QC71_TRIPLE_PROFILE_TO_NOTIFICATION[slimbook.info.SLB_QC71_PROFILE_ENERGY_SAVER]
+                        
 
                 elif (event == common.SLB_EVENT_AC_ONLINE):
                     ac = True
-
+                    
+                    if ((family == slimbook.info.SLB_MODEL_CREATIVE or family == slimbook.info.SLB_MODEL_EVO) and module_loaded):
+                        
+                        # restore profile
+                        logger.debug("AC Online")
+                        slimbook.qc71.profile_set(restore_profile)
+                        event = common.QC71_TRIPLE_PROFILE_TO_NOTIFICATION[restore_profile]
+                        
                 elif (event & 0xfff0 == common.SLB_EVENT_UPOWER_POWER_EVENT):
                     if (expect_upower_event):
                         logger.debug("Expected UPower event, nothing to do")
                         expect_upower_event = False
                         continue
 
-                    # Evo and Creative doesn't change TDP without AC'
-                    if (ac == False and (family == slimbook.info.SLB_MODEL_CREATIVE or family == slimbook.info.SLB_MODEL_EVO)):
+                    # Creative doesn't change TDP without AC'
+                    if (ac == False and (family == slimbook.info.SLB_MODEL_CREATIVE)):
                         continue
 
                     if (family in common.QC71_TRIPLE_PROFILE):
                         expect = common.QC71_TRIPLE_PROFILE_FROM_UPOWER[event]
                         logger.debug("external power event {0:04X}, expected {1:04X}".format(event,expect))
                         slimbook.qc71.profile_set(expect)
-                        event = expect
+                        event = common.QC71_TRIPLE_PROFILE_TO_NOTIFICATION[expect]
                         
                     elif (family in common.QC71_DOUBLE_PROFILE):
                         expect = common.QC71_DOUBLE_PROFILE_FROM_UPOWER[event]
                         logger.debug("external power event {0:04X}, expected {1:04X}".format(event,expect))
                         slimbook.qc71.profile_set(expect)
-                        event = expect
+                        event = common.QC71_DOUBLE_PROFILE_TO_NOTIFICATION[expect]
 
         if (event == common.SLB_EVENT_TOUCHPAD_CHANGED):
             if (not settings[common.OPT_TRACKPAD_LOCK]):
@@ -442,7 +460,7 @@ def main():
                 #discard event
                 continue
                     
-        logger.debug("out event {0}".format(event))
+        logger.debug("out event {0:04X}".format(event))
         send_notify(event)
         
 if __name__=="__main__":
